This is a live mirror of the Perl 5 development currently hosted at https://github.com/perl/perl5
Generalize macro and move to handy.h
[perl5.git] / time64.h
index cea1be9..c065766 100644 (file)
--- a/time64.h
+++ b/time64.h
@@ -1,8 +1,8 @@
 #include <time.h>
 #include "time64_config.h"
 
-#ifndef TIME64_H
-#    define TIME64_H
+#ifndef PERL_TIME64_H_
+#    define PERL_TIME64_H_
 
 
 /* Set our custom types */
@@ -28,10 +28,12 @@ struct TM64 {
 #endif
 
 #ifdef HAS_TM_TM_ZONE
/* If glibc is defined, use const. Otherwise,
* if we are on android, use const but not with g++
  */
-#  if defined(__GLIBC__) || (defined(__ANDROID__) && !defined(__cplusplus))
+#  if defined(__GLIBC__) || (defined(__ANDROID__) && !defined(__cplusplus)) \
+    || defined(__QNX__) || defined(__CYGWIN__)
         const
 #  endif
         char    *tm_zone;
@@ -48,9 +50,8 @@ struct TM64 {
 
 
 /* Declare functions */
-static struct TM *S_gmtime64_r    (const Time64_T *, struct TM *);
-static struct TM *S_localtime64_r (const Time64_T *, struct TM *);
-static Time64_T   S_timegm64      (struct TM *);
+struct TM *Perl_gmtime64_r    (const Time64_T *, struct TM *);
+struct TM *Perl_localtime64_r (const Time64_T *, struct TM *);
 
 
 /* Not everyone has gm/localtime_r(), provide a replacement */
@@ -28,10 +28,12 @@ struct TM64 {
 
 #ifdef HAS_TM_TM_ZONE
-/* If glibc is defined, use const. Otherwise,
- * if we are on android, use const but not with g++
+/* If glibc is defined or we are on QNX, use const.
+ * Otherwise, if we are on android, use const but
+ * not with g++.
  */